@@ -1,8 +1,5 @@
 package Net::CLI::Interact::ActionSet;
-{
-  $Net::CLI::Interact::ActionSet::VERSION = '2.142720';
-}
-
+$Net::CLI::Interact::ActionSet::VERSION = '2.400002';
 use Moo;
 use Sub::Quote;
 use MooX::Types::MooseLike::Base qw(InstanceOf ArrayRef CodeRef RegexpRef);
@@ -165,20 +162,14 @@ sub _marshall_responses {
 
 1;
 
-# ABSTRACT: Conversation of Send and Match Actions
-
-
-__END__
 =pod
 
+=for Pod::Coverage BUILDARGS has_current_match has_default_continuation
+
 =head1 NAME
 
 Net::CLI::Interact::ActionSet - Conversation of Send and Match Actions
 
-=head1 VERSION
-
-version 2.142720
-
 =head1 DESCRIPTION
 
 This class is used internally by L<Net::CLI::Interact> and it's unlikely that
@@ -229,7 +220,7 @@ with the Action(s) according to how many are required.
 
 =head2 register_callback
 
-Allows the L<Transport|Net::CLI::Interact::Transport> to be registered
+Allows the Transport to be registered
 such that when the ActionSet is executed, commands are sent to the registered
 callback subroutine. May be called more than once, and on execution each of
 the callbacks will be run, in turn and in order.
@@ -287,16 +278,5 @@ L<Net::CLI::Interact::Role::Iterator>
 
 =back
 
-=head1 AUTHOR
-
-Oliver Gorwits <oliver@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2014 by Oliver Gorwits.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
 
